@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2019-2020 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
+ *  Copyright (C) 2019-2021 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
  *
  *  Authors: Mickey Sola
  *
@@ -22,7 +22,7 @@
 #include "clamav-config.h"
 #endif
 
-#if defined(FANOTIFY)
+#if defined(HAVE_SYS_FANOTIFY_H)
 
 #include <stdio.h>
 #include <unistd.h>
@@ -36,13 +36,16 @@
 
 #include <sys/fanotify.h>
 
-#include "libclamav/clamav.h"
-#include "libclamav/scanners.h"
+// libclamav
+#include "clamav.h"
+#include "scanners.h"
 
-#include "shared/optparser.h"
-#include "shared/output.h"
+// shared
+#include "optparser.h"
+#include "output.h"
 
-#include "clamd/server.h"
+// clamd
+#include "server.h"
 
 #include "../inotif/hash.h"
 #include "../inotif/inotif.h"
@@ -50,7 +53,7 @@
 #include "../client/client.h"
 
 #include "../scan/thread.h"
-#include "../scan/queue.h"
+#include "../scan/onas_queue.h"
 
 #include "../misc/utils.h"
 
@@ -64,12 +67,10 @@ cl_error_t onas_setup_fanotif(struct onas_context **ctx)
 {
 
     const struct optstruct *pt;
-    short int scan;
-    unsigned int sizelimit = 0, extinfo;
-    uint64_t fan_mask      = FAN_EVENT_ON_CHILD;
+    uint64_t fan_mask = FAN_EVENT_ON_CHILD;
 
-    pthread_attr_t ddd_attr;
-    struct ddd_thrarg *ddd_tharg = NULL;
+    const struct optstruct *pt_tmpdir;
+    const char *clamd_tmpdir;
 
     ddd_pid = 0;
 
@@ -92,6 +93,13 @@ cl_error_t onas_setup_fanotif(struct onas_context **ctx)
         (*ctx)->fan_mask |= FAN_ACCESS | FAN_OPEN;
     }
 
+    pt_tmpdir = optget((*ctx)->clamdopts, "TemporaryDirectory");
+    if (pt_tmpdir->enabled) {
+        clamd_tmpdir = pt_tmpdir->strarg;
+    } else {
+        clamd_tmpdir = cli_gettmpdir();
+    }
+
     if ((pt = optget((*ctx)->clamdopts, "OnAccessMountPath"))->enabled) {
         while (pt) {
             if (fanotify_mark(onas_fan_fd, FAN_MARK_ADD | FAN_MARK_MOUNT, (*ctx)->fan_mask, (*ctx)->fan_fd, pt->strarg) != 0) {
@@ -108,6 +116,14 @@ cl_error_t onas_setup_fanotif(struct onas_context **ctx)
     } else {
         if ((pt = optget((*ctx)->clamdopts, "OnAccessIncludePath"))->enabled) {
             while (pt) {
+                if (0 == strcmp(clamd_tmpdir, pt->strarg)) {
+                    logg("!ClamFanotif: Not watching path '%s'\n", pt->strarg);
+                    logg("!ClamFanotif: ClamOnAcc should not watch the directory clamd is using for temp files\n");
+                    logg("!ClamFanotif: Consider setting TemporaryDirectory in clamd.conf to a different directory.\n");
+                    pt = (struct optstruct *)pt->nextarg;
+                    continue;
+                }
+
                 if (fanotify_mark(onas_fan_fd, FAN_MARK_ADD, (*ctx)->fan_mask, (*ctx)->fan_fd, pt->strarg) != 0) {
                     logg("!ClamFanotif: can't include path '%s'\n", pt->strarg);
                     return CL_EARG;
@@ -130,8 +146,6 @@ cl_error_t onas_setup_fanotif(struct onas_context **ctx)
         logg("*ClamFanotif: file size limit disabled\n");
     }
 
-    extinfo = optget((*ctx)->clamdopts, "ExtendedDetectionInfo")->enabled;
-
     return CL_SUCCESS;
 }
 
@@ -140,14 +154,13 @@ int onas_fan_eloop(struct onas_context **ctx)
     int ret     = 0;
     int err_cnt = 0;
     short int scan;
-    STATBUF sb;
     fd_set rfds;
     char buf[4096];
     ssize_t bread;
     struct fanotify_event_metadata *fmd;
+    char proc_fd_fname[1024];
     char fname[1024];
-    int len, check, fres;
-    char err[128];
+    int len, check;
 
     FD_ZERO(&rfds);
     FD_SET((*ctx)->fan_fd, &rfds);
@@ -191,9 +204,9 @@ int onas_fan_eloop(struct onas_context **ctx)
         while (FAN_EVENT_OK(fmd, bread)) {
             scan = 1;
             if (fmd->fd >= 0) {
-                sprintf(fname, "/proc/self/fd/%d", fmd->fd);
+                sprintf(proc_fd_fname, "/proc/self/fd/%d", fmd->fd);
                 errno = 0;
-                len   = readlink(fname, fname, sizeof(fname) - 1);
+                len   = readlink(proc_fd_fname, fname, sizeof(fname) - 1);
                 if (len == -1) {
                     close(fmd->fd);
                     logg("!ClamFanotif: internal error (readlink() failed), %d, %s\n", fmd->fd, strerror(errno));
