@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2013-2020 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
+ *  Copyright (C) 2013-2021 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
  *  Copyright (C) 2007-2013 Sourcefire, Inc.
  *
  *  Authors: Török Edvin
@@ -2070,5 +2070,9 @@ static struct cli_element entities_htable_elements[] = {
     {NULL, 0, 0},
     {NULL, 0, 0},
 };
+#ifndef PROFILE_HASHTABLE
 const struct cli_hashtable entities_htable = {
+#else
+struct cli_hashtable entities_htable = {
+#endif
     entities_htable_elements, 2048, 743, 1638};
